﻿using System;
using System.Collections.Generic;
using System.Data;
using System.IO;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Infragistics.Documents.Excel;
using Infragistics.Web.UI.GridControls;

public partial class _Default : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        ImportExcel();

        ImportCSVFile();
    }

    private void ImportExcel()
    {
        //Create the temporary table to store data
        DataTable myDataTable = new DataTable();
        DataColumn myDataColumn;
        DataRow myDataRow;

        //MIN/MAX Values used to frame the working size of the Excel data to be imported.
        int minCellRow = Int32.MaxValue;
        int maxCellRow = Int32.MinValue;
        int minCellColumn = Int32.MaxValue;
        int maxCellColumn = Int32.MinValue;

        Workbook internalWorkBook = Workbook.Load(Request.PhysicalApplicationPath + "Northwind.xls");

        foreach (WorksheetRow row in internalWorkBook.Worksheets["Customers"].Rows)
        {
            foreach (WorksheetCell cell in row.Cells)
            {
                if (cell.Value != null)
                {
                    //Logic For Determining the Range of Rows/Columns in the Excel File.
                    minCellRow = Math.Min(minCellRow, cell.RowIndex);
                    maxCellRow = Math.Max(maxCellRow, cell.RowIndex);
                    minCellColumn = Math.Min(minCellColumn, cell.ColumnIndex);
                    maxCellColumn = Math.Max(maxCellColumn, cell.ColumnIndex);
                }
            }
        }


        for (int i = minCellColumn; i <= maxCellColumn; i++)
        {
            //Get the column name
            string columnName =
                    internalWorkBook.Worksheets["Customers"].Rows[minCellRow].Cells[i].Value.ToString();

            //The export that was demonstrated earlier utilizes the first row
            //for the column header.  We can now use that to give column names.
            myDataColumn = new DataColumn(columnName);

            //Add the columns to the datatable.
            myDataTable.Columns.Add(myDataColumn);
        }

        for (int rowIndex = minCellRow + 1; rowIndex <= maxCellRow; rowIndex++)
        {
            //Create a new DataRow
            myDataRow = myDataTable.NewRow();

            //Loop through the columns and associate the value to each cell
            for (int columnIndex = minCellColumn; columnIndex <= maxCellColumn; columnIndex++)
            {
                myDataRow[columnIndex] =
    internalWorkBook.Worksheets["Customers"].Rows[rowIndex].Cells[columnIndex].Value;
            }

            //Add The Row to a DataTable
            myDataTable.Rows.Add(myDataRow);
        }

        //Set the primary key so that the WebDataGrid can perform Auto Crud
        myDataTable.PrimaryKey = new DataColumn[] { myDataTable.Columns["CustomerID"] };

        //ImportGrid below is the grid that we have on our page
        WebDataGrid1.DataSource = myDataTable;
        WebDataGrid1.DataBind();
    }

    private void ImportCSVFile()
    {
        DataTable myDataTable = new DataTable();
        DataColumn myDataColumn;
        DataRow myDataRow;

        string strFileName = Request.PhysicalApplicationPath + "Example1.csv";

        var reader = new StreamReader(File.OpenRead(strFileName));
        List<string> listA = new List<string>();
        List<string> listB = new List<string>();

        bool firstLine = true;


        while (!reader.EndOfStream)
        {
            var line = reader.ReadLine();
            var values = line.Split(',');

            if (firstLine)
            {
                for (int i = 0; i < values.Length; i++)
                {
                    string columnName = values[i];

                    myDataColumn = new DataColumn(columnName);
                    myDataTable.Columns.Add(myDataColumn);
                }

                firstLine = false;
            }
            else
            {
                myDataRow = myDataTable.NewRow();

                for (int i = 0; i < values.Length; i++)
                {
                    myDataRow[i] = values[i];
                }

                myDataTable.Rows.Add(myDataRow);
            }

        }

        WebDataGrid2.DataSource = myDataTable;
        WebDataGrid2.DataBind();
    }
}